/*  GNOME-DB Rolodex
 *  Copyrigth (C) 2000 Rodrigo Moya
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
#if !defined(__gnomedb_rolodex_h__)
#  define __gnomedb_rolodex_h__

#include <gnome-db.h>
#if defined(HAVE_CONFIG_H)
#  include <config.h>
#endif

/*
 * Callbacks
 */
extern void rolodex_quit_cb (GtkWidget *w, gpointer data);

/*
 * Global variables
 */
extern GtkWidget*      glb_mainwin;
extern GdaConnection* glb_connection;

#endif
